AccountTimezoneObject

Struct AccountTimezoneObject 

pub struct AccountTimezoneObject {
    pub account_timezone: AccountTimezone,
}
Example

use twitter_archive::structs::account_timezone::AccountTimezoneObject;

let json = r#"{
  "accountTimezone": {
    "accountId": "111111111",
    "timeZone": "Arizona"
  }
}"#;

let data: AccountTimezoneObject = serde_json::from_str(&json).unwrap();

// De-serialized properties
assert_eq!(data.account_timezone.account_id, "111111111");
assert_eq!(data.account_timezone.time_zone, "Arizona");

// Re-serialize is equivalent to original data without pretty printing
assert_eq!(serde_json::to_string_pretty(&data).unwrap(), json);

Fields

account_timezone: AccountTimezone

Why they wrapped a list of time zones within unnecessary object label is anyone’s guess

Example JSON data

{
  "accountTimezone": {
    "accountId": "111111111",
    "timeZone": "Arizona"
  }
}