CommunityNoteRating

Struct CommunityNoteRating 

pub struct CommunityNoteRating {
    pub not_helpful_tags: Vec<String>,
    pub note_id: String,
    pub helpfulness_level: String,
    pub created_at: DateTime<Utc>,
    pub user_id: String,
}
Example

use chrono::{DateTime, NaiveDateTime, Utc};

use twitter_archive::convert::date_time_iso_8601::FORMAT;

use twitter_archive::structs::community_note_rating::CommunityNoteRating;

let created_at_string = "2020-01-20T21:42:09.068Z";
let created_at_native_time = NaiveDateTime::parse_from_str(&created_at_string, FORMAT).unwrap();
let created_at_date_time = DateTime::<Utc>::from_naive_utc_and_offset(created_at_native_time, Utc);

let json = format!(r#"{{
  "notHelpfulTags" : [
    "OpinionSpeculation",
    "NoteNotNeeded"
  ],
  "noteId" : "9999999999999999999",
  "helpfulnessLevel" : "NotHelpful",
  "createdAt" : "{created_at_string}",
  "userId" : "111111111"
}}"#);

let data: CommunityNoteRating = serde_json::from_str(&json).unwrap();

// De-serialized properties
assert_eq!(data.not_helpful_tags.len(), 2);
assert_eq!(data.not_helpful_tags[0], "OpinionSpeculation");
assert_eq!(data.not_helpful_tags[1], "NoteNotNeeded");

assert_eq!(data.note_id, "9999999999999999999");
assert_eq!(data.helpfulness_level, "NotHelpful");
assert_eq!(data.created_at, created_at_date_time);
assert_eq!(data.user_id, "111111111");

// Re-serialize is equivalent to original data without pretty printing
assert_eq!(serde_json::to_string(&data).unwrap(), json.replace("\n", "").replace(" ", ""));

Fields

not_helpful_tags: Vec<String>

List of tags about why community note was not helpful

Example JSON data

{
  "notHelpfulTags" : [
    "OpinionSpeculation",
    "NoteNotNeeded"
  ]
}
note_id: String

Example JSON data

{ "noteId" : "9999999999999999999" }
helpfulness_level: String

Example JSON data

{ "helpfulnessLevel" : "NotHelpful" }
created_at: DateTime<Utc>

Example JSON data

{ "createdAt" : "2020-01-20T21:42:09.068Z" }
user_id: String

Example JSON data

{ "userId" : "111111111" }