pub struct AccountTimezoneObject {
pub account_timezone: AccountTimezone,
}Expand description
Example
use twitter_archive::structs::account_timezone::AccountTimezoneObject;
let json = r#"{
"accountTimezone": {
"accountId": "111111111",
"timeZone": "Arizona"
}
}"#;
let data: AccountTimezoneObject = serde_json::from_str(&json).unwrap();
// De-serialized properties
assert_eq!(data.account_timezone.account_id, "111111111");
assert_eq!(data.account_timezone.time_zone, "Arizona");
// Re-serialize is equivalent to original data without pretty printing
assert_eq!(serde_json::to_string_pretty(&data).unwrap(), json);Fields
account_timezone: AccountTimezoneWhy they wrapped a list of time zones within unnecessary object label is anyone’s guess
Example JSON data
{
"accountTimezone": {
"accountId": "111111111",
"timeZone": "Arizona"
}
}Trait Implementations
Sourceimpl Clone for AccountTimezoneObject
impl Clone for AccountTimezoneObject
Sourcefn clone(&self) -> AccountTimezoneObject
fn clone(&self) -> AccountTimezoneObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountTimezoneObject
impl Debug for AccountTimezoneObject
Sourceimpl<'de> Deserialize<'de> for AccountTimezoneObject
impl<'de> Deserialize<'de> for AccountTimezoneObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AccountTimezoneObject
impl Display for AccountTimezoneObject