pub struct CommunityNoteRating {
pub not_helpful_tags: Vec<String>,
pub note_id: String,
pub helpfulness_level: String,
pub created_at: DateTime<Utc>,
pub user_id: String,
}Expand description
Example
use chrono::{DateTime, NaiveDateTime, Utc};
use twitter_archive::convert::date_time_iso_8601::FORMAT;
use twitter_archive::structs::community_note_rating::CommunityNoteRating;
let created_at_string = "2020-01-20T21:42:09.068Z";
let created_at_native_time = NaiveDateTime::parse_from_str(&created_at_string, FORMAT).unwrap();
let created_at_date_time = DateTime::<Utc>::from_naive_utc_and_offset(created_at_native_time, Utc);
let json = format!(r#"{{
"notHelpfulTags" : [
"OpinionSpeculation",
"NoteNotNeeded"
],
"noteId" : "9999999999999999999",
"helpfulnessLevel" : "NotHelpful",
"createdAt" : "{created_at_string}",
"userId" : "111111111"
}}"#);
let data: CommunityNoteRating = serde_json::from_str(&json).unwrap();
// De-serialized properties
assert_eq!(data.not_helpful_tags.len(), 2);
assert_eq!(data.not_helpful_tags[0], "OpinionSpeculation");
assert_eq!(data.not_helpful_tags[1], "NoteNotNeeded");
assert_eq!(data.note_id, "9999999999999999999");
assert_eq!(data.helpfulness_level, "NotHelpful");
assert_eq!(data.created_at, created_at_date_time);
assert_eq!(data.user_id, "111111111");
// Re-serialize is equivalent to original data without pretty printing
assert_eq!(serde_json::to_string(&data).unwrap(), json.replace("\n", "").replace(" ", ""));Fields
List of tags about why community note was not helpful
Example JSON data
{
"notHelpfulTags" : [
"OpinionSpeculation",
"NoteNotNeeded"
]
}note_id: StringExample JSON data
{ "noteId" : "9999999999999999999" }helpfulness_level: StringExample JSON data
{ "helpfulnessLevel" : "NotHelpful" }created_at: DateTime<Utc>Example JSON data
{ "createdAt" : "2020-01-20T21:42:09.068Z" }user_id: StringExample JSON data
{ "userId" : "111111111" }Trait Implementations
Sourceimpl Clone for CommunityNoteRating
impl Clone for CommunityNoteRating
Sourcefn clone(&self) -> CommunityNoteRating
fn clone(&self) -> CommunityNoteRating
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommunityNoteRating
impl Debug for CommunityNoteRating
Sourceimpl<'de> Deserialize<'de> for CommunityNoteRating
impl<'de> Deserialize<'de> for CommunityNoteRating
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for CommunityNoteRating
impl Display for CommunityNoteRating